<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">License</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Brightness</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Hardware Backlight</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="78"/>
        <location filename="../defaultlook.cpp" line="629"/>
        <location filename="../defaultlook.cpp" line="648"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="699"/>
        <location filename="../defaultlook.cpp" line="709"/>
        <location filename="../defaultlook.cpp" line="737"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="156"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>Window Manager</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>Appearance</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="129"/>
        <source>Xfce Settings</source>
        <translation>Xfce Settings</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="320"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="227"/>
        <location filename="../defaultlook.ui" line="1452"/>
        <source>Affects 1st panel</source>
        <translation>Affects 1st panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <location filename="../defaultlook.ui" line="1475"/>
        <source>Left</source>
        <translation>Left</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="285"/>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Right</source>
        <translation>Right</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="204"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Bottom</source>
        <translation>Bottom</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="259"/>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Top</source>
        <translation>Top</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="164"/>
        <location filename="../defaultlook.ui" line="303"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="310"/>
        <source>Display panel horizontally</source>
        <translation>Display panel horizontally</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="171"/>
        <source>Display panel vertically</source>
        <translation>Display panel vertically</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="211"/>
        <source>Restore default panel</source>
        <translation>Restore default panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="181"/>
        <source>Backup current panel configuration</source>
        <translation>Backup current panel configuration</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Restore backup panel configuration</source>
        <translation>Restore backup panel configuration</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <location filename="../defaultlook.ui" line="405"/>
        <location filename="../defaultlook.ui" line="561"/>
        <location filename="../defaultlook.ui" line="886"/>
        <location filename="../defaultlook.ui" line="893"/>
        <location filename="../defaultlook.ui" line="900"/>
        <location filename="../defaultlook.ui" line="1016"/>
        <location filename="../defaultlook.ui" line="1417"/>
        <location filename="../defaultlook.ui" line="1610"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <source>Apply</source>
        <translation>Apply</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="384"/>
        <source>Theme</source>
        <translation>Theme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="428"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Fix HexChat input box in dark theme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="435"/>
        <source>Preview</source>
        <translation>Preview</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="442"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Fix some website fields when using dark theme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="445"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox dark theme tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="452"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="459"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="486"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Save Current Settings as a Theme Set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="497"/>
        <source>Remove User Theme Set</source>
        <translation>Remove User Theme Set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="514"/>
        <source>Theme Options</source>
        <translation>Theme Options</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="537"/>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="547"/>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="581"/>
        <source>Transparency and shadow options</source>
        <translation>Transparency and shadow options</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Edit compton.conf directly in text editor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="598"/>
        <source>Edit compton.conf</source>
        <translation>Edit compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="648"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="659"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="669"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>off</source>
        <translation>off</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="700"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="705"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="713"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="716"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Settings</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Launch compton-conf configuration tool</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>Compton settings</source>
        <translation>Compton settings</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="744"/>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="752"/>
        <source>Hardware Backlight</source>
        <translation>Hardware Backlight</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="759"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="786"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Choose Display for xrandr tweaks</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>Resolution</source>
        <translation>Resolution</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="803"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="813"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Brightness</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <location filename="../defaultlook.ui" line="917"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="827"/>
        <source>GTK scaling</source>
        <translation>GTK scaling</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>xrandr Scaling</source>
        <translation>xrandr Scaling</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Config Options</source>
        <translation>Config Options</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1047"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Reset Thunar custom right-click actions to system defaults</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="996"/>
        <source>Enable single-click on desktop</source>
        <translation>Enable single-click on desktop</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="951"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Enable single-click in Thunar File Manager</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1054"/>
        <source>Enable Desktop Zoom </source>
        <translation>Enable Desktop Zoom </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="975"/>
        <location filename="../defaultlook.ui" line="1570"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Show windows from all workspaces in panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1003"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Disable shortening of long filenames on the desktop</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="989"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Enable hibernate on Log Out menu </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="968"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   note: to hibernate, swap needs to be &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="958"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="982"/>
        <source>Thunar windows always open in split view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1061"/>
        <source>Thunar split view opens horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1071"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1079"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1118"/>
        <location filename="../defaultlook.ui" line="1154"/>
        <source>Off</source>
        <translation>Off</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1123"/>
        <source>On Hover</source>
        <translation>On Hover</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1141"/>
        <location filename="../defaultlook.ui" line="1162"/>
        <source>Autohide</source>
        <translation>Autohide</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Reset ALL mx-fluxbox settings</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Placement</source>
        <translation>Placement</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <source>Reset DefaultDock</source>
        <translation>Reset DefaultDock</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <source>Toggle desktop icons</source>
        <translation>Toggle desktop icons</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Reset Fluxbox Menu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1345"/>
        <location filename="../defaultlook.ui" line="1577"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1352"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1359"/>
        <source>Width</source>
        <translation>Width</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1366"/>
        <source>Toggle icon captions</source>
        <translation>Toggle icon captions</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1373"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1380"/>
        <source>Height</source>
        <translation>Height</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1387"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1390"/>
        <source>Upgrade existing menu entries</source>
        <translation>Upgrade existing menu entries</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1438"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1493"/>
        <source>Systray Icon Size</source>
        <translation>Systray Icon Size</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1504"/>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1509"/>
        <source>Small</source>
        <translation>Small</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1514"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1519"/>
        <source>Large</source>
        <translation>Large</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1524"/>
        <source>Larger</source>
        <translation>Larger</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1529"/>
        <source>Largest</source>
        <translation>Largest</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1556"/>
        <source>Workspace</source>
        <translation>Workspace</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1563"/>
        <source>Enable single-click</source>
        <translation>Enable single-click</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1584"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Reset KDE/Plasma defaults</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1624"/>
        <source>Other</source>
        <translation>Other</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1691"/>
        <source>Password for administrative tasks:</source>
        <translation>Password for administrative tasks:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1639"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Use tearfree radeon driver option</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1698"/>
        <source>&amp;User</source>
        <translation>&amp;User</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1705"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Enable kernel sandbox</source>
        <translation>Enable kernel sandbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1677"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1719"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Reset Lightdm (login screen) to system default theme</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1684"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1632"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Enable mounting of internal drives by non-root users</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1712"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Use tearfree amdgpu option</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1660"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1424"/>
        <source>Manage Tint2 Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1667"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1670"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1777"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>About</source>
        <translation>About</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1857"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1874"/>
        <source>Quit application</source>
        <translation>Quit application</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1884"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display switch only valid for Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="628"/>
        <source>About MX Tweak</source>
        <translation>About MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="631"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>App for quick default ui theme changes and tweaks</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="634"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="648"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Finished! Firefox may require a restart for changes to take effect</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>Plese remove special characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>from file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="710"/>
        <source>File name already exists.  Choose another name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="738"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="741"/>
        <source>Archive does not contain a panel config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="861"/>
        <source>Panel settings</source>
        <translation>Panel settings</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="862"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1563"/>
        <source>settings</source>
        <translation>settings</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1903"/>
        <source>Choose a theme set</source>
        <translation>Choose a theme set</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Remove User Theme Set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>New Theme Set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Enter name for new theme set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Window Buttons</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Show button labels</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Show flat buttons</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Show handle</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sorting Order:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Timestamp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Group title and timestamp</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Window Title</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Group title and window title</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>None, allow drag-and-drop</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Window grouping:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Never</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Always</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Middle click action:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Nothing</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Close window</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimize window</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restore minimized windows to current workspace</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Draw window frame when hovering over a button</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Switch windows using the mouse wheel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Show windows from all workspaces or viewports</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Show only minimized windows</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Show windows from all monitors</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Close</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Popup Windows</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Windows during move</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Window decorations</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Show shadows under dock windows</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Show shadows under popup windows</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Windows during resize</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Show shadows under regular windows</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Show windows preview in place of icons when cycling</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Display fullscreen overlay windows directly</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inactive windows</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchronize drawing to vertical blank</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Settings</translation>
    </message>
</context>
</TS>
